==> openshift-model-operatorhub-5.10.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/OperatorBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OperatorBuilder extends io.fabric8.openshift.api.model.operatorhub.v1.OperatorFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1.OperatorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1.Operator,io.fabric8.openshift.api.model.operatorhub.v1.OperatorBuilder>{
  public OperatorBuilder() {
    this(false);
  }
  public OperatorBuilder(java.lang.Boolean validationEnabled) {
    this(new Operator(), validationEnabled);
  }
  public OperatorBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorFluent<?> fluent) {
    this(fluent, false);
  }
  public OperatorBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Operator(), validationEnabled);
  }
  public OperatorBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1.Operator instance) {
    this(fluent, instance, false);
  }
  public OperatorBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1.Operator instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OperatorBuilder(io.fabric8.openshift.api.model.operatorhub.v1.Operator instance) {
    this(instance,false);
  }
  public OperatorBuilder(io.fabric8.openshift.api.model.operatorhub.v1.Operator instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1.OperatorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1.Operator build() {
    Operator buildable = new Operator(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OperatorBuilder that = (OperatorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-6.2.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/OperatorBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OperatorBuilder extends OperatorFluentImpl<OperatorBuilder> implements VisitableBuilder<Operator,OperatorBuilder>{
  public OperatorBuilder() {
    this(false);
  }
  public OperatorBuilder(Boolean validationEnabled) {
    this(new Operator(), validationEnabled);
  }
  public OperatorBuilder(OperatorFluent<?> fluent) {
    this(fluent, false);
  }
  public OperatorBuilder(OperatorFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Operator(), validationEnabled);
  }
  public OperatorBuilder(OperatorFluent<?> fluent,Operator instance) {
    this(fluent, instance, false);
  }
  public OperatorBuilder(OperatorFluent<?> fluent,Operator instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OperatorBuilder(Operator instance) {
    this(instance,false);
  }
  public OperatorBuilder(Operator instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  OperatorFluent<?> fluent;
  Boolean validationEnabled;
  public Operator build() {
    Operator buildable = new Operator(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
